@@ -5,6 +5,6 @@ from .. import Matcher
 
 class _be_false(Matcher):
     def _match(self, subject):
-        return subject is False
+        return subject is False, []
 
 be_false = _be_false()
