@@ -9,7 +9,7 @@ class be_within(Matcher):
         self._stop = stop
 
     def _match(self, subject):
-        return self._start < subject < self._stop
+        return self._start < subject < self._stop, []
 
-    def _description(self, subject):
+    def __repr__(self):
         return 'be within {start} and {stop}'.format(start=self._start, stop=self._stop)
